;;; FLX_MAIN.LSP
;;; ================================================================
;;; (C)opyright FELIX Computer Aided Technologies GmbH 1995-97
;;; ================================================================
;;; Created: Jan 20, 1996 vp
;;; Changed: Sep 27, 1996 vp
;;;          Jun 10, 1997 vp: (getfiled ... 16) for 3.0
;;; ================================================================
;;; This file is called by FE_STUP.LSP
;;; Global variable FLX$DIRECTORY for application search path 
;;; is set in f#_stup.lsp
;;; ================================================================


(if (not FLX$DIRECTORY)
    (progn
        (ALERT 
            "Fatal Error: System's UTILS Directory not found !"
        )
        (exit)
    )
)


;;; ****************************************************************
;;; ****************************************************************
;;; Lisp defined COMMANDS
;;; ****************************************************************
;;; ****************************************************************

;;; SETUP: Drawing Setup: Units, Precision

(defun C:SETUP()
    (setfunhelp "C:SETUP" "SETUP")
    (FLX_LOADLISP "FLX_SETUP" "_setp")
    (princ)
)

;;; ================================================================
;;; FILE MENU
;;; ================================================================

;;; FILEMAN: File Manager

(defun C:FILEMAN( / drawing_dir lib_fn)
    (setfunhelp "C:FILEMAN" "Parts Library")
    (defun *error*(msg) (FLX_FUNC_EXIT)(princ))
    (setq drawing_dir (cdr (assoc "FCADDWG" (getenv))))
    (if (setq lib_fn (findfile (strcat drawing_dir "\\drawing.plb")))
       (princ) ;;; 
       (setq lib_fn (getfiled "File Manager" "" "plb" 0))
    )
    (if lib_fn (progn
      (setvar "CMDECHO" 0)
      (command ".PARTLIB" lib_fn)
      (setvar "CMDECHO" 1)
    ))
    (FLX_FUNC_EXIT)
    (princ)
)

(defun C:DMANAGER()
    (setfunhelp "C:DMANAGER" "Parts Library")
    (C:FILEMAN)
    (princ)
)
   
;;; ----------------------------------------------------------------
;;; PALMAN: Palette Manager
;;;    The Palette Manager does not use file names, but 
;;;    verbal descriptions to load a palette

(defun C:PALMAN() 
    (setfunhelp "C:PALMAN" "PALMAN")
    (FLX_LOADLISP "FLX_PALMAN" "_pal")
    (princ)
)

;;; ----------------------------------------------------------------
;;; Application Manager: Commands DLGEDIT, BMPEDIT etc.

(if (setq tmp (findfile (strcat FLX$DIRECTORY "flx_appm.lsp")))
    (LOAD tmp)
)
(setq tmp nil)

;;; ----------------------------------------------------------------
;;; LISTFILE: Display Text File in Dialog Box

(setfunhelp "C:LISTFILE" "Resource Manager")

(defun C:LISTFILE()
    (if (not FLX_LISTFILE)
      (load (strcat FLX$DIRECTORY "flx_lstf.lsp"))
    )
    (FLX_LISTFILE nil "lsp,dlg,mcr,mnu,mnp,cmd,lin,pat,*") 
    (princ)
)

;;; ================================================================
;;; EDIT MENU
;;; ================================================================

;;; COPYPROP: Copy properties from one entity to others

(defun C:COPYPROP()
    (setfunhelp "C:COPYPROP" "COPYPROP")
    (FLX_LOADLISP "FLX_COPYPROP" "_pcop")
    (princ)
)

;;; PROPLAYER: Modify Layer Property of selected entities

(defun C:PROPLAYER()
    (setfunhelp "C:PROPLAYER" "PROPLAYER")
    (FLX_LOADLISP "FLX_PROPLAYER" "_play")
    (princ)
)

;;; XPLODE: Filtered Explode Dialog Box

(defun C:XPLODE()
    (setfunhelp "C:XPLODE" "Explode")
    (FLX_LOADLISP "FLX_XPLODE" "_xpld")
    (princ)
)

;;; Inquiry Commands

;;; EINFO: Object Information Dialog 

(delcmd "EINFO") ;;; Redefined !

(defun C:EINFO()
    (setfunhelp "C:EINFO" "EINFO")
    (FLX_LOADLISP "FLX_EINFO" "_einf")
    (princ)
)

;;; TABLES:  Drawing Table Information Dialog

(defun C:TABLES()
    (setfunhelp "C:TABLES" "TABLES")
    (FLX_LOADLISP "FLX_TABLES" "_tabl")
    (princ)
)

;;; TABSERVICE: Table Service Dialog (added: Sept 1, 1996)

(defun C:TABSERVICE()
;;; (setfunhelp "C:TABLES" "TABLES")  ;;; ###
    (FLX_LOADLISP "FLX_TABSERVICE" "_tabm")
    (princ)
)

;;; ================================================================
;;; MENU DRAW 
;;; ================================================================

;;; TRAPEZOID: Draw 2D-cone

(setfunhelp "C:TRAPEZOID" "Cone2D")

(defun C:TRAPEZOID()                 
   (if (findfile "cone2d.lsp")
      (progn 
        (setq C:TRAPEZOID nil)
        (load "cone2d.lsp")
        (C:TRAPEZOID)
      )
      (ALERT
        "File CONE2D.LSP not found in application directory!"
        "Alert"
        "EXCLAMATION"
      )
   )
   (princ)
)

;;; ================================================================
;;; MENU MODIFY
;;; ================================================================

;;; REJOIN: Rejoin broken lines or arcs. Xloaded - see below

(setfunhelp "C:REJOIN" "REJOIN")

(if C:REJOIN (xunload "rejoin.dll")) ;;; !!!
(if (setq tmp (findfile (strcat FLX$DIRECTORY "rejoin.dll")))
    (XLOAD tmp)
)
(setq tmp nil)

;;; ================================================================
;;; MENU DETAIL
;;; ================================================================

;;; RTEXT: Reference Text

(defun C:RTEXT()
    (setfunhelp "C:RTEXT" "RTEXT")
    (FLX_LOADLISP "FLX_RTEXT" "_rtxt")
    (princ) 
)

;;; TCORRECT: Text Utility - Global or single line text modification

(defun C:TCORRECT()
    (setfunhelp "C:TCORRECT" "TCORRECT")
    (FLX_LOADLISP "FLX_TCORRECT" "_tcor")
    (princ)
)

;;; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
;;; DIM:     Dimensioning Options Dialog Box  
;;; DIMDRAW: Create Dimension Dialog Box
;;; DIMEDIT: Edit Dimension Dialog Box 

(defun C:DIM()
    (setfunhelp "C:DIM" "Dimensioning Summary")
    (FLX_FUNC_INIT)
    (if (not FLX_DIMDIALOG) (load (strcat FLX$DIRECTORY "flx_dim.lsp")) ) 
    (FLX_DIMDIALOG "flx_dlg" "DIM")
    (FLX_FUNC_EXIT)
    (princ)
)

(defun C:DIMDRAW()
    (setfunhelp "C:DIMDRAW" "Dimensioning Summary")
    (FLX_FUNC_INIT)
    (if (not FLX_DIMDIALOG) (load (strcat FLX$DIRECTORY "flx_dim.lsp")) ) 
    (FLX_DIMDIALOG "flx_dlg" "DimDraw")
    (FLX_FUNC_EXIT)
    (princ)
)

(defun C:DIMEDIT()
    (setfunhelp "C:DIMEDIT" "Dimensioning Summary")
    (FLX_FUNC_INIT)
    (if (not FLX_DIMDIALOG) (load (strcat FLX$DIRECTORY "flx_dim.lsp")) ) 
    (FLX_DIMDIALOG "flx_dlg" "DimEdit")
    (FLX_FUNC_EXIT)
    (princ)
)

;;; DIMREST

(delcmd "DIMREST")   ;;; There is the DIMTYPE dialog...

;;; DIMREST redefined:

(defun C:DIMREST()   
    (setfunhelp "C:DIMREST" "Dimensioning Summary")
    (FLX_LOADLISP "FLX_DIMREST" "_dim")
    (princ)
)

;;; ----------------------------------------------------------------

(defun C:SPLINE()
;;; (setfunhelp "C:SPLINE" "SPLINE") ;;; ###
    (FLX_LOADLISP "FLX_SPLINE" "_spln")
    (princ)
)

(defun C:PCURVE()
;;; (setfunhelp "C:PCURVE" "PCURVE") ;;; ###
    (FLX_LOADLISP "FLX_PCURVE" "_spln")
    (princ)
)

;;; ================================================================
;;; MENU PART
;;; ================================================================

;;; LIBRARY: Call current part library

(defun C:LIBRARY( / fn) 
    (setfunhelp "C:LIBRARY" "PARTLIB")
    (defun *ERROR*(msg) (setvar "CMDECHO" 1)(setq *ERROR* nil)(princ))
    (setvar "CMDECHO" 0)
    (if FLX$CURRLIB 
      (if (findfile FLX$CURRLIB)
        (princ FLX$CURRLIB)
        (setq FLX$CURRLIB nil) 
      )
    )
    (if FLX$CURRLIB
      (command ".PARTLIB" FLX$CURRLIB)
      (progn
         (C:SETLIB)
         (if FLX$CURRLIB (command ".PARTLIB" FLX$CURRLIB))
      )
    )
    (setvar "CMDECHO" 1)(setq *ERROR* nil)
    (princ)
)

;;; SETLIB: Set current library for LIBRARY command

(defun C:SETLIB ( / title prevlib fn)
    (setfunhelp "C:SETLIB" "PARTLIB")
    (setq title "Set Current Part Library / Symbol Library")
    (defun *ERROR*(msg) (setvar "CMDECHO" 1)(setq *ERROR* nil)(princ))
    (setvar "CMDECHO" 0)
    (setq prevlib FLX$CURRLIB)
    (if (setq fn (GETFILED title (if FLX$CURRLIB FLX$CURRLIB "") "plb" 0))
      (progn
        (if (findfile fn)
          (progn
            (setq FLX$CURRLIB fn)
            (princ FLX$CURRLIB)
            (terpri)
          )
          (setq FLX$CURRLIB prevlib) ;;; else
        )
      )
      (setq FLX$CURRLIB prevlib) ;;; else
    )
    (setvar "CMDECHO" 1)(setq *ERROR* nil)
    (princ)
)

;;; INSERTQ: Insert Quick

(defun C:INSERTQ() 
    (setfunhelp "C:INSERTQ" "QINSERT")
    (FLX_FUNC_INIT)
    (setvar "CMDECHO" 0)
    (command ".QINSERT" "?" "_F" "1" "1" "_R" "CMDECHO-ON" "0")
    (FLX_FUNC_EXIT)
    (princ)
) 

;;; MERGE Part (File Dialog) ... 

(defun C:MERGE( / fn flag)
    (setfunhelp "C:MERGE" "QINSERT")
    (FLX_FUNC_INIT)
    (setq flag 16) ;;; ###VP 01.05.97: 0 --> 16
    (if (setq fn (GETFILED "Insert External Part File" "" "flx" flag)) 
         (progn
           ;;; (flxnames) (getactvp)
           (setvar "CMDECHO" 0)
           (command ".QINSERT" fn "_F" "1" "1" "_R" "CMDECHO-ON"  "0") 
         )
    )
    (FLX_FUNC_EXIT)
    (princ)
)

;;; ----------------------------------------------------------------
;;; ATTRIBUTE EDITING: Move, Rotate, Change value of an Attribute


(defun C:ATTVALUE()
    (setfunhelp "C:ATTVALUE" "Attribute Modification")
    (FLX_LOADLISP "FLX_ATTQEDIT" "_atte")
    (princ)
)
(defun C:ATTMOVE()
    (setfunhelp "C:ATTMOVE" "Attribute Modification")
    (FLX_LOADLISP "FLX_ATTMOVE" "_atte")
    (princ)
)
(defun C:ATTROT()
    (setfunhelp "C:ATTROT" "Attribute Modification")
    (FLX_LOADLISP "FLX_ATTROT" "_atte")
    (princ)
)

;;; ----------------------------------------------------------------
;;; ATTEXP: Export Attribute Information

(defun C:ATTEXP()
    (setfunhelp "C:ATTEXP" "ATTEXP")
    (FLX_LOADLISP "FLX_ATTEXP" "_aexp")
    (princ)
)

;;; ================================================================
;;; MENU OPTIONS
;;; ================================================================

;;; QLAYER: Quick Layer Modification

(defun C:QLAYER ()
    (setfunhelp "C:QLAYER " "QLAYER ")
    (FLX_LOADLISP "FLX_QLAYER" "_qlay")
    (princ)
)

;;; ================================================================
;;; MENU VIEW
;;; ================================================================

;;; DEFUN: Zoom to the drawings page size defined by
;;; the local system variables LIMMIN and LIMMAX
;;; No funhelp required


(defun C:ZOOMPAGE() (ZOOMPAGE)(princ))  

(defun ZOOMPAGE()
    (defun *error* (msg) (setq *error* nil) (setvar "CMDECHO" 1)(princ))
    (setvar "CMDECHO" 0)
    (command ".ZOOMWIN"  (getvar "LIMMIN") (getvar "LIMMAX") )
    (setvar "CMDECHO" 1)
    (setq *error* nil) 
    (princ)
)

;;; ================================================================
;;; MENU HELP
;;; ================================================================

;;; TUTOR

;;; Test, if aphelp.lsp is already loaded. Otherwise load it...

(defun FLX_TUTOR_INIT( /  p_tmp temp )
  (if (not APEXERCISES)(progn 
    (if (setq p_tmp (findfile "aphelp.lsp")) 
      (setq APT_APPATH (strcat (substr p_tmp 1 (- (strlen p_tmp) 10))))
      (if (setq p_tmp (findfile 
            (strcat 
              (substr (setq temp (cdr (assoc "FCADCMD" (getenv)))) 1 (- (strlen temp) 8))
              "TUTOR\\aphelp.lsp"
            )     ;;; ### 8 = FCAD_BIN
          ))
        (setq APT_APPATH (strcat (substr p_tmp 1 (- (strlen p_tmp) 10))))
      ) 
    )
    (if (not p_tmp) 
       (ALERT
           (if (= (getvar "LANGUAGE") 1)
               "\nDatei 'aphelp.lsp' nicht gefunden!"
               "\nFile 'aphelp.lsp' not found!"
           ) 
           "Tutor"
           "STOP"
       )
       (load p_tmp)
    )
  ))
)

;;; Display Palette for Tutorial

(defun C:TUTOR() 
    (FLX_TUTOR_INIT)(APTUTORIAL) 
    (princ)
)

;;; Display Palette for Exercises

(defun C:EXERCISE() 
    (FLX_TUTOR_INIT)(APEXERCISES)
    (princ)
)



;;; *************************************************************************
;;; ***************************************************************
;;; GLOBAL FUNCTIONS           ************************************
;;; ***************************************************************
;;; *************************************************************************

;;; *************************************************************************
;;; FUNCTION LIBRARY: INIT and EXIT functions & Error Handling
;;; *************************************************************************

;;; ### DEFUN FLX_FUNC_INIT / FLX_FUNC_EXIT:
;;; ### Note: Use only with tested functions !

(defun FLX_FUNC_INIT()
   (if (< (getvar "ACTDB") 0)
      (progn 
          (defun *error*(msg)
             (setq *error* nil)  ;;; CMDECHO ?
             (princ)
          )
          (EXIT)                    ;;; Warning: Program terminated by EXIT
          (setq *error* nil)
      )
      (progn                        ;;; User break etc.
          (defun *error*(msg) 
             (setvar "CMDECHO" 1)   ;;;### !!!
             (setvar "FILEDIA" 1)   ;;;### !!!
             (setvar "ATTDIA" 1)    ;;;### !!!
             (setq *error* nil)
             (princ)
          )
      )     
   ) 
   (princ)
)

;;; ------------------------------------------------------------------------

(defun FLX_FUNC_EXIT() 
   (setvar "CMDECHO" 1)
   (setvar "FILEDIA" 1)
   (setvar "ATTDIA" 1)   
   (setq *error* nil)
   (princ)
)

;;; ===============================================================
;;; PALETTE FUNCTIONS

;;; The function PALMEMBER tests, if the filename fn is member of
;;; the currently opened palettes:

(defun PALMEMBER(fn / fn pal_list n pal pos mem_list)
    (setq pal_list '() n 1)
    (repeat 10
       (setq pal (strcase (getvar (strcat "PALETTE" (itoa n)))))
       (setq pal_list (cons pal pal_list))
       (setq n (1+ n))
    )
    (setq pal_list (reverse pal_list))
    (if  (setq mem_list (member (strcase fn) pal_list))
          (setq pos (1+ (- 10 (length mem_list))))
          (setq pos nil)
    )
)

(defun PALNEXTPOS( / pos) (setq pos (PALMEMBER "")) )

(defun PALNEXT(fn / fn fn2 pos cmdecho)
    (setq cmdecho (getvar "CMDECHO"))
    (if (setq fn2 (findfile fn)) 
       (if (setq pos (PALMEMBER fn2))
         (ALERT 
            (if (= (getvar "LANGUAGE") 1) ;;; German
               (strcat "Palette " fn2 "\nbereits an Position " (itoa pos) " geladen.") 
               (strcat "Palette " fn2 "\nalready loaded at position " (itoa pos) ".") 
            )
            (if (= (getvar "LANGUAGE") 1) "Achtung" "Alert")
            "EXCLAMATION"
          )
          (progn
             (if (setq pos (PALNEXTPOS))
               (setq pos (strcat "P" (itoa pos)))
               (setq pos "P10")
             )
             (setvar "CMDECHO" 0)
             (command ".PALOPEN" pos "Auto" fn2)
          )
        )
        (ALERT 
             (if (= (getvar "LANGUAGE") 1)
                 (strcat "Palette " (strcase fn) " nicht gefunden!")
                 (strcat "Palette " (strcase fn) " not found!")
             )
             (if (= (getvar "LANGUAGE") 1) "Achtung" "Alert")
             "EXCLAMATION"
          )
    )
    (setvar "CMDECHO" cmdecho)
    (princ)
)

;;; ### DEFUN QPALNEXT (Temp Function, obsolete because of PALOPEN revision):
;;; ### Command for Menus, Macros: Set next free palette to specified 
;;; ### MNP file name

(defun C:QPALNEXT( / fn fn2 pos)
    (setq fn (getstring (if (= (getvar "LANGUAGE") 1) "Dateiname: " "Filename: ")))
    (if fn (PALNEXT fn))
    (princ)
)

;;; ===============================================================
;;; DEFUN: CALL_WINEXE 
;;; ---------------------------------------------------------------
;;; Call a Windows Executable Program
;;;   (CALL_WINEXE <program_name>)
;;; Directory Search Path:
;;; - Current Directory
;;; - Windows Directory (win.com)
;;; - Windows System Directory
;;; - Directory of FCAD.EXE        
;;; - Directories as set by PATH environment variable
;;; - Mapped Network directories
;;; ---------------------------------------------------------------

(defun CALL_WINEXE(prog / prog flx_dll)
   (setq flx_dll "fl_stup.dll")                
   (if (findfile (strcat FLX$DIRECTORY flx_dll))
      (progn
         (if (not CALL_EXE)
             (xload (strcat FLX$DIRECTORY flx_dll))
         )
         (CALL_EXE prog)
         (xunload flx_dll)      
      ) 
      (ALERT
          (if (= (getvar "LANGUAGE") 1) 
              (strcat 
                 "Datei "  flx_dll " nicht gefunden!"
                 "\nKann Programm " (strcase prog)  " nicht ausfhren!"
              )
              (strcat
                 "File "  flx_dll " not found!"
                 "\nUnable to execute program " (strcase prog)  "!"
              )
          )
          (if (= (getvar "LANGUAGE") 1) "Achtung" "Alert")
          "EXCLAMATION"
      )
   )
   (princ)
)

;;; ===============================================================

;;; Hourglass Cursor
;;; (HOURGLASS  <1|0> ) ; Argument: 1=On / 0=OFF 

(defun HOURGLASS (x / x)
    (if (not sanduhr_on) 
      (xload (strcat FLX$DIRECTORY "fl_stup.dll"))  
    )
    (if sanduhr_on  (if (= x 1)(sanduhr_on) (sanduhr_off)) )
    (xunload "fl_stup.dll")  
    (princ)
)

;;; ===============================================================

;;; CLIPCOPY 
;;;      ... copies any string from the supplied list to the clipboard
;;; 
;;; (CLIPCOPY <string-list> )


(defun CLIPCOPY(copylst / copylst)
    (if copylst  (progn 
      (if (not COPYCLIP)
          (xload (strcat FLX$DIRECTORY "fl_stup.dll"))  
      )
      (COPYCLIP copylst)
      (xunload "fl_stup")
    ))
    (princ)
)

;;; COPYCLIPBOARD

(defun COPYCLIPBOARD ( / lines flag1 copylst REQUEST_INIT el dlg_fname dlg_id)
    (defun REQUEST_INIT()
      (if FLX$WIN95 (foreach n '("IDCANCEL" "Selection" "All" "Static1")
           (Dlg_TileSetFont n 2)
      ))
      ;;; 2=All 1=Selection 0=NOTHING
      (Dlg_TileAction "IDCANCEL"  "(setq flag1 0)(Dlg_DialogDone)")
      (Dlg_TileAction "Selection" "(setq flag1 1)(Dlg_DialogDone)")
      (Dlg_TileAction "All"       "(setq flag1 2)(Dlg_DialogDone)")
    )
    (setq flag1 2 copylst '())    
    (setq lines (Dlg_TileGet "ListBox1"))
    (setq lines (strcat lines "\n"))
    (setq lines (read (strcat "(" lines ")" )))
    (if lines 
      (if (FLX_DLGDSP "flx_dlg" "Request" "(princ)" "(REQUEST_INIT)") (princ)(exit))
    )
    (cond 
     ((= flag1 1)
      (foreach el lines (setq copylst (append copylst (list (nth el lst)))))
     )
     ((= flag1 2)
      (setq copylst lst)
     )
    )
    (if copylst (progn 
      (if (not COPYCLIP)
          (xload (strcat FLX$DIRECTORY "fl_stup.dll")) 
      )
      (COPYCLIP copylst)    
      (xunload "fl_stup")
    ))
)

;;; ===============================================================
;;; Lisp / FDT Loading Functions

;;; FLX_LOADLISP <function_name> <lisp_filename>

(defun FLX_LOADLISP(func_name lisp_file / tmp func_name lisp_file)
  (if (eval (read func_name))
     (eval (read (strcat "(" func_name ")")))
     (progn
        (if (setq tmp (findfile (strcat FLX$DIRECTORY "flx" lisp_file ".lsp") ) )   
           (progn 
              (princ (strcat 
                    (if (= (getvar "LANGUAGE") 1) "Lade " "Loading ")
                    tmp "..."
              ))      
              (load tmp)
              (princ " OK.")
              (terpri)
              (eval (read (strcat "(" func_name ")")))
           ) 
           (ALERT
               (strcat 
                    (if (= (getvar "LANGUAGE") 1) "Datei flx" "File flx")
                    lisp_file 
                    (if (= (getvar "LANGUAGE") 1) ".lsp nicht gefunden!" ".lsp not found!") 
                 )
                (if (= (getvar "LANGUAGE") 1) "Achtung" "Alert")
                "EXCLAMATION"
          )
        )
     )
  )
  (princ)
)


;;; FLX_XLOAD <function> <DLL_filename> 

(defun FLX_XLOAD(s1 s2 / s1 s2)
    (if (/= (type (eval (read s1))) 'EXSUBR)
      (if (= (xload s2 T) T) 
        (progn  (xunload s2) (xload s2))
      )
    )
)

;;; ===============================================================
;;; General Dialog Functions

;;; Dlg_ListAction 

(defun Dlg_ListAction (box_id box_list / box_id box_list)
    (Dlg_ListStart box_id)
    (mapcar 'Dlg_ListAdd box_list)
    (Dlg_ListEnd)
)

;;; Display Dialog 
;;; Note:  * from certain FCAD directory: FLX$DIRECTORY  *

(defun FLX_DLGDSP (dlg_file dlg_name callbk_new callbk_start /
                         dlg_id dlg_fname lang lang1 lang2
                         dlg_file1 dlg_file2 return)
  
    (if (= (setq lang (getvar "LANGUAGE")) 2)
       (setq lang1 "" lang2 (itoa lang))
       (setq lang1 (itoa lang) lang2 "")
    )
    (setq dlg_file1 (strcat dlg_file lang1 ".dlg"))
    (setq dlg_fname (findfile (strcat FLX$DIRECTORY dlg_file1)))    
    (if (not dlg_fname) (progn
      (setq dlg_file2 (strcat dlg_file lang2 ".dlg"))
      (setq dlg_fname (findfile (strcat FLX$DIRECTORY dlg_file2)))
    ))
    (if dlg_fname 
      (progn
        (setq dlg_id (Dlg_DialogLoad dlg_fname))
        (Dlg_DialogNew dlg_name dlg_id)  ;;; ### callbk_new
        (Dlg_DialogStart callbk_start)
        (Dlg_DialogUnload dlg_id)
        (setq return T)
      )
      (progn 
        (ALERT 
           (if (= (getvar "LANGUAGE") 1)
               (strcat "Dialog Datei nicht gefunden: " dlg_file1) 
               (strcat "Dialog file not found: " dlg_file1) 
           )
           (if (= (getvar "LANGUAGE") 1) "Achtung" "Alert")
               "EXCLAMATION"
        )
        (setq return nil)
      )
    )
)

;;; - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 

(defun FLX_DefaultAction ()
    (setq value $value data $data key $key reason $reason var_x $x var_y $y) 
    (if FLX$TESTDIALOG     
     (progn
        (terpri)
        (princ "\n$key:       ")(princ $key)
        (princ " --- Type: ")   (princ (type $key))
        (princ "\n$value:     ")(princ $value)
        (princ " --- Type: ")   (princ (type $value))
        (princ "\n   $reason: ")(princ $reason)
        (princ " --- Type: ")   (princ (type $reason))
        (princ "\n   $x:      ")(princ $x)
        (princ " --- Type: ")   (princ (type $x))
        (princ "\n   $y:      ")(princ $y)
        (princ " --- Type: ")   (princ (type $y))
        (princ "\n   $data:   ")(princ $data)
        (princ " --- Type: ")   (princ (type $data))
     )
     (princ)
    )
    (princ)
)

;;; *************************************************************************
;;; Load additional lisp file(s)...
;;; *************************************************************************

(if (not FLX_AF)
   (if (setq tmp (findfile (strcat FLX$DIRECTORY "flx_test.lsp"))) (load tmp))
)
(setq tmp nil)

;;; *************************************************************************

(princ)

